@@ -30,7 +30,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.70';
+$VERSION = '1.72';
 
 sub ProcessFujiDir($$$);
 sub ProcessFaceRec($$$);
@@ -53,8 +53,10 @@ my %testedRAF = (
     '0212' => 'S3Pro Ver2.12',
     '0216' => 'S3Pro Ver2.16', # (NC)
     '0218' => 'S3Pro Ver2.18',
+    '0240' => 'X-E1 Ver2.40',
     '0264' => 'F700 Ver2.00',
     '0266' => 'S9500 Ver1.01',
+    '0261' => 'X-E1 Ver2.61',
     '0269' => 'S9500 Ver1.02',
     '0271' => 'S3Pro Ver2.71', # UV/IR model?
     '0300' => 'X-E2',
@@ -710,8 +712,9 @@ my %faceCategories = (
     0x1446 => { #12
         Name => 'FlickerReduction',
         Writable => 'int32u',
+        # seen values: Off=0x0000, On=0x2100,0x3100
         PrintConv => q{
-            my $on = ((($val >> 12) & 0xff) == 3) ? 'On' : 'Off';
+            my $on = ((($val >> 8) & 0x0f) == 1) ? 'On' : 'Off';
             return sprintf('%s (0x%.4x)', $on, $val);
         },
         PrintConvInv => '$val=~/(0x[0-9a-f]+)/i; hex $1',
